@@ -1,15 +1,14 @@
 /******************************************************************************
-** $Id: config.h,v 1.2 1999/12/18 22:04:46 gerd Exp $
+** $Id: config.h,v 1.1 1997/12/06 22:56:00 gerd Exp $
 **=============================================================================
 ** 
 ** This file is part of BibTool.
 ** It is distributed under the GNU General Public License.
 ** See the file COPYING for details.
 ** 
-** (c) 1996-1999 Gerd Neugebauer
+** (c) 1996-2002 Gerd Neugebauer
 ** 
-** Net: gerd.neugebauer@sdm.de
-**      gerd.neugebauer@gmx.de
+** Net: gene@gerd-neugebauer.de
 ** 
 ******************************************************************************/
 
@@ -24,7 +23,7 @@
 **  DON'T FORGET THE CURRENT DIRECTORY.
 **  To clear it set it to NULL.
 **  This can also be specified in the Makefile. This value is used if no
-**  Makefile is used or the macro is not set in the Makefile.
+**  Makefile is used or the macro is not set in the makefile.
 */
 #ifndef RSC_BIBTOOL_DEFAULT
 #define RSC_BIBTOOL_DEFAULT NULL
@@ -84,21 +83,20 @@
 #define RSC_BIBINPUTS       "BIBINPUTS"
 
 /*-----------------------------------------------------------------------------
-**  Define the name of an environment variable containing a list of
-**  file names separated by the first character in ENV_SEP (see below).
-**  These files are loaded as resource files if they exist.
-**  Undefine this macro if no such feature is present in your system.
-**  If it is undefined then DefaultResourceFiles is used to find a
-**  default resource file.
+**  Define the name of the default resource file name.
+**  On MSDOS-like maschines I recommend "bibtool.rsc"
 */
-#define RSC_ENV_VAR         "BIBTOOLRSC"
+#ifdef MSDOS
+#define DefaultResourceFile "bibtool.rsc"
+#else
+#define DefaultResourceFile ".bibtoolrsc"
+#endif
 
 /*-----------------------------------------------------------------------------
-**  Define the names of the default resource file name. The value is a 
-**  comma separated list of strings. Those file names are tried in
-**  turn until a file can be read.
+**  Define the name of an environment variable containing a resource file name.
+**  Undefine this macro if no such feature is present in your system.
 */
-#define DefaultResourceFiles ".bibtoolrsc",".bibtoolrc","bibtool.rsc",".bibtool"
+#define RSC_ENV_VAR         "BIBTOOLRSC"
 
 /*-----------------------------------------------------------------------------
 **  Define the name of an environment variable of the resource search path.
