@@ -1,15 +1,14 @@
 /******************************************************************************
-** $Id: database.c,v 1.9 1999/12/18 22:04:46 gerd Exp $
+** $Id: database.c,v 1.8 1997/12/03 11:50:30 gerd Exp $
 **=============================================================================
 ** 
 ** This file is part of BibTool.
 ** It is distributed under the GNU General Public License.
 ** See the file COPYING for details.
 ** 
-** (c) 1996-1999 Gerd Neugebauer
+** (c) 1996-2002 Gerd Neugebauer
 ** 
-** Net: gerd.neugebauer@sdm.de
-**      gerd.neugebauer@gmx.de
+** Net: gene@gerd-neugebauer.de
 ** 
 **-----------------------------------------------------------------------------
 ** Description:
@@ -39,25 +38,24 @@
 #else
 #define _ARG(A) ()
 #endif
- DB new_db _ARG((void));
- Record db_find _ARG((DB db,Uchar *key));
- Uchar * db_new_key _ARG((DB db,Uchar *key));
- Uchar * db_string _ARG((DB db,Uchar *s,int localp));
- int *db_count _ARG((DB db,int *lp));
- int *db_count_special _ARG((DB db,int *lp));
- int read_db _ARG((DB db,char *file,int (*fct)_ARG((DB,Record)),int verbose));
- static Record insert_record _ARG((Record rec,Record ptr,int (*less)_ARG((Record,Record))));
- static Record rec__sort _ARG((Record rec,int (*less)_ARG((Record,Record))));
- static int cmp_heap _ARG((Record r1,Record r2));
- static void mark_string _ARG((Record rec,Uchar *s));
- void db_add_record _ARG((DB db,Record rec));
- void db_forall _ARG((DB db,int (*fct)_ARG((DB,Record))));
- void db_mac_sort _ARG((DB db));
- void db_rewind _ARG((DB db));
- void db_sort _ARG((DB db,int (*less)_ARG((Record,Record))));
- void delete_record _ARG((DB db,Record rec));
- void free_db _ARG((DB db));
- void print_db _ARG((FILE *file,DB db,char *spec));
+ DB new_db _ARG((void));			   /* database.c             */
+ Record db_find _ARG((DB db,Uchar *key));	   /* database.c             */
+ Uchar * db_new_key _ARG((DB db,Uchar *key));	   /* database.c             */
+ Uchar * db_string _ARG((DB db,Uchar *s,int localp));/* database.c           */
+ int *db_count _ARG((DB db,int *lp));		   /* database.c             */
+ int read_db _ARG((DB db,char *file,int (*fct)_ARG((DB,Record)),int verbose));/* database.c*/
+ static Record insert_record _ARG((Record rec,Record ptr,int (*less)_ARG((Record,Record))));/* database.c*/
+ static Record rec__sort _ARG((Record rec,int (*less)_ARG((Record,Record))));/* database.c*/
+ static int cmp_heap _ARG((Record r1,Record r2));  /* database.c             */
+ static void mark_string _ARG((Record rec,Uchar *s));/* database.c           */
+ void db_add_record _ARG((DB db,Record rec));	   /* database.c             */
+ void db_forall _ARG((DB db,int (*fct)_ARG((DB,Record))));/* database.c      */
+ void db_mac_sort _ARG((DB db));		   /* database.c             */
+ void db_rewind _ARG((DB db));			   /* database.c             */
+ void db_sort _ARG((DB db,int (*less)_ARG((Record,Record))));/* database.c   */
+ void delete_record _ARG((DB db,Record rec));	   /* database.c             */
+ void free_db _ARG((DB db));			   /* database.c             */
+ void print_db _ARG((FILE *file,DB db,char *spec));/* database.c             */
 
 /*****************************************************************************/
 /* External Programs                                                         */
@@ -797,45 +795,6 @@ Uchar * db_string(db,s,localp)			   /*                        */
 ** Returns:	Static array containing the statistics.
 **___________________________________________________			     */
 int *db_count(db,lp)				   /*                        */
-  DB     db;				   	   /*                        */
-  int    *lp;				   	   /*                        */
-{ int    *count;				   /*                        */
-  Record rec;				   	   /*                        */
- 						   /*                        */
-  count = db_count_special(db,lp);		   /*                        */
-					       	   /*                        */
-  if ( (rec=DBnormal(db)) != RecordNULL )	   /*                        */
-  { while ( PrevRecord(rec) != RecordNULL ) rec = PrevRecord(rec);/*         */
-    while ( rec != RecordNULL )			   /*                        */
-    { count[RecordType(rec)]++;			   /*                        */
-      rec = NextRecord(rec);			   /*                        */
-    }						   /*                        */
-  }						   /*                        */
-						   /*                        */
-  return count;					   /*                        */
-}						   /*------------------------*/
-
-/*-----------------------------------------------------------------------------
-** Function:	db_count_special()
-** Purpose:	Count all special entries in a database. This includes normal
-**		aswell as special records. The result is stored in a
-**		static array which is reused by |db_count()|. A
-**		pointer to this array is returned. The indices
-**		correspond to the entry types defined with
-**		|add_entry_type()| or declared as symbolic constants
-**		in |entry.h|. 
-**
-**		The end of the array is marked by an element
-**		containing a negative number. In addition the argument
-**		|lp| can point to an integer where the number of valid
-**		elements is stored. If |lp| is |NULL| this step is
-**		omitted. 
-** Arguments:
-**	db	Database to count.
-**	lp	pointer to an integer for the length.
-** Returns:	Static array containing the statistics.
-**___________________________________________________			     */
-int *db_count_special(db,lp)			   /*                        */
   DB         db;				   /*                        */
   int        *lp;				   /*                        */
 { static int *count;				   /*                        */
@@ -861,48 +820,55 @@ int *db_count_special(db,lp)			   /*                        */
   for ( i=0; i<len; i++ ) count[i] = 0;		   /*                        */
   count[len-1] = -1;				   /*                        */
 						   /*                        */
-  if ( (rec=DBstring(db)) != RecordNULL )	   /*                        */
-  { while ( PrevRecord(rec) != RecordNULL ) rec = PrevRecord(rec);/*         */
-    while ( rec != RecordNULL )			   /*                        */
-    { count[BIB_STRING]++;			   /*                        */
-      rec = NextRecord(rec);			   /*                        */
-    }						   /*                        */
-  }						   /*                        */
-  if ( (rec=DBcomment(db)) != RecordNULL )	   /*                        */
-  { while ( PrevRecord(rec) != RecordNULL ) rec = PrevRecord(rec);/*         */
-    while ( rec != RecordNULL )			   /*                        */
-    { count[BIB_COMMENT]++;			   /*                        */
-      rec = NextRecord(rec);			   /*                        */
-    }						   /*                        */
-  }						   /*                        */
-  if ( (rec=DBpreamble(db)) != RecordNULL )	   /*                        */
-  { while ( PrevRecord(rec) != RecordNULL ) rec = PrevRecord(rec);/*         */
-    while ( rec != RecordNULL )			   /*                        */
-    { count[BIB_PREAMBLE]++;			   /*                        */
-      rec = NextRecord(rec);			   /*                        */
-    }						   /*                        */
-  }						   /*                        */
-  if ( (rec=DBalias(db)) != RecordNULL )	   /*                        */
-  { while ( PrevRecord(rec) != RecordNULL ) rec = PrevRecord(rec);/*         */
-    while ( rec != RecordNULL )			   /*                        */
-    { count[BIB_ALIAS]++;			   /*                        */
-      rec = NextRecord(rec);			   /*                        */
-    }						   /*                        */
-  }						   /*                        */
-  if ( (rec=DBmodify(db)) != RecordNULL )	   /*                        */
-  { while ( PrevRecord(rec) != RecordNULL ) rec = PrevRecord(rec);/*         */
-    while ( rec != RecordNULL )			   /*                        */
-    { count[BIB_MODIFY]++;			   /*                        */
-      rec = NextRecord(rec);			   /*                        */
-    }						   /*                        */
-  }						   /*                        */
-  if ( (rec=DBinclude(db)) != RecordNULL )	   /*                        */
-  { while ( PrevRecord(rec) != RecordNULL ) rec = PrevRecord(rec);/*         */
-    while ( rec != RecordNULL )			   /*                        */
-    { count[BIB_INCLUDE]++;			   /*                        */
-      rec = NextRecord(rec);			   /*                        */
-    }						   /*                        */
-  }						   /*                        */
- 						   /*                        */
+  if ( (rec=DBstring(db)) != RecordNULL )
+  { while ( PrevRecord(rec) != RecordNULL ) rec = PrevRecord(rec);
+    while ( rec != RecordNULL )
+    { count[BIB_STRING]++;
+      rec = NextRecord(rec);
+    }
+  }
+  if ( (rec=DBcomment(db)) != RecordNULL )
+  { while ( PrevRecord(rec) != RecordNULL ) rec = PrevRecord(rec);
+    while ( rec != RecordNULL )
+    { count[BIB_COMMENT]++;
+      rec = NextRecord(rec);
+    }
+  }
+  if ( (rec=DBpreamble(db)) != RecordNULL )
+  { while ( PrevRecord(rec) != RecordNULL ) rec = PrevRecord(rec);
+    while ( rec != RecordNULL )
+    { count[BIB_PREAMBLE]++;
+      rec = NextRecord(rec);
+    }
+  }
+  if ( (rec=DBalias(db)) != RecordNULL )
+  { while ( PrevRecord(rec) != RecordNULL ) rec = PrevRecord(rec);
+    while ( rec != RecordNULL )
+    { count[BIB_ALIAS]++;
+      rec = NextRecord(rec);
+    }
+  }
+  if ( (rec=DBmodify(db)) != RecordNULL )
+  { while ( PrevRecord(rec) != RecordNULL ) rec = PrevRecord(rec);
+    while ( rec != RecordNULL )
+    { count[BIB_MODIFY]++;
+      rec = NextRecord(rec);
+    }
+  }
+  if ( (rec=DBinclude(db)) != RecordNULL )
+  { while ( PrevRecord(rec) != RecordNULL ) rec = PrevRecord(rec);
+    while ( rec != RecordNULL )
+    { count[BIB_INCLUDE]++;
+      rec = NextRecord(rec);
+    }
+  }
+  if ( (rec=DBnormal(db)) != RecordNULL )
+  { while ( PrevRecord(rec) != RecordNULL ) rec = PrevRecord(rec);
+    while ( rec != RecordNULL )
+    { count[RecordType(rec)]++;
+      rec = NextRecord(rec);
+    }
+  }
+						   /*                        */
   return count;					   /*                        */
 }						   /*------------------------*/
