@@ -1,15 +1,14 @@
 /******************************************************************************
-** $Id: database.h,v 1.8 1999/12/18 22:04:46 gerd Exp $
+** $Id: database.h,v 1.7 1997/12/03 11:50:30 gerd Exp $
 **=============================================================================
 ** 
 ** This file is part of BibTool.
 ** It is distributed under the GNU General Public License.
 ** See the file COPYING for details.
 ** 
-** (c) 1996-1999 Gerd Neugebauer
+** (c) 1996-2002 Gerd Neugebauer
 ** 
-** Net: gerd.neugebauer@sdm.de
-**      gerd.neugebauer@gmx.de
+** Net: gene@gerd-neugebauer.de
 ** 
 **-----------------------------------------------------------------------------
 ** Description:
@@ -149,21 +148,20 @@
 #else
 #define _ARG(A) ()
 #endif
- DB new_db _ARG((void));
- Record db_find _ARG((DB db,Uchar *key));
- Uchar * db_new_key _ARG((DB db,Uchar *key));
- Uchar * db_string _ARG((DB db,Uchar *s,int localp));
- int *db_count _ARG((DB db,int *lp));
- int *db_count_special _ARG((DB db,int *lp));
- int read_db _ARG((DB db,char *file,int (*fct)_ARG((DB,Record)),int verbose));
- void db_add_record _ARG((DB db,Record rec));
- void db_forall _ARG((DB db,int (*fct)_ARG((DB,Record))));
- void db_mac_sort _ARG((DB db));
- void db_rewind _ARG((DB db));
- void db_sort _ARG((DB db,int (*less)_ARG((Record,Record))));
- void delete_record _ARG((DB db,Record rec));
- void free_db _ARG((DB db));
- void print_db _ARG((FILE *file,DB db,char *spec));
+ DB new_db _ARG((void));			   /* database.c             */
+ Record db_find _ARG((DB db,Uchar *key));	   /* database.c             */
+ Uchar * db_new_key _ARG((DB db,Uchar *key));	   /* database.c             */
+ Uchar * db_string _ARG((DB db,Uchar *s,int localp));/* database.c           */
+ int *db_count _ARG((DB db,int *lp));		   /* database.c             */
+ int read_db _ARG((DB db,char *file,int (*fct)_ARG((DB,Record)),int verbose));/* database.c*/
+ void db_add_record _ARG((DB db,Record rec));	   /* database.c             */
+ void db_forall _ARG((DB db,int (*fct)_ARG((DB,Record))));/* database.c      */
+ void db_mac_sort _ARG((DB db));		   /* database.c             */
+ void db_rewind _ARG((DB db));			   /* database.c             */
+ void db_sort _ARG((DB db,int (*less)_ARG((Record,Record))));/* database.c   */
+ void delete_record _ARG((DB db,Record rec));	   /* database.c             */
+ void free_db _ARG((DB db));			   /* database.c             */
+ void print_db _ARG((FILE *file,DB db,char *spec));/* database.c             */
 
 /*---------------------------------------------------------------------------*/
 
