@@ -1,15 +1,14 @@
 /******************************************************************************
-** $Id: error.h,v 2.21 1999/12/18 22:04:46 gerd Exp $
+** $Id: error.h,v 2.20 1997/12/03 11:50:30 gerd Exp $
 **=============================================================================
 ** 
 ** This file is part of BibTool.
 ** It is distributed under the GNU General Public License.
 ** See the file COPYING for details.
 ** 
-** (c) 1996-1999 Gerd Neugebauer
+** (c) 1996-2002 Gerd Neugebauer
 ** 
-** Net: gerd.neugebauer@sdm.de
-**      gerd.neugebauer@gmx.de
+** Net: gene@gerd-neugebauer.de
 ** 
 **-----------------------------------------------------------------------------
 ** Description:
@@ -76,10 +75,6 @@
 #define ERR_EXIT      256
 
 
- extern char  *err_fmt1;
- extern char  *err_fmt2;
- extern char  *err_fmt3;
- extern char  *err_fmt4;
  extern char  *err_format;
  extern Uchar *err_point;
  extern Uchar *err_oom;
@@ -258,6 +253,21 @@
 **___________________________________________________			     */
 #define ErrPrintF2(F,A,B)	(void)fprintf(err_file,F,A,B)
 
+/*-----------------------------------------------------------------------------
+** Macro:	ErrPrintF3()
+** Type:	void
+** Purpose:	Apply a formatting instruction (with |printf()|). This
+**		macro takes a format string and three additional arguments
+**		which are determined by the formatting string.
+** Arguments:
+**	F	Format
+**	A	First argument.
+**	B	Second argument.
+**	C	Third argument.
+** Returns:	nothing
+**___________________________________________________			     */
+#define ErrPrintF3(F,A,B,C)	(void)fprintf(err_file,F,A,B,C)
+
 /*-----------------------------------------------------------------------------
 ** Constant:	FlushErr()
 ** Type:	void
@@ -276,7 +286,7 @@
 **	A	Verbose message.
 ** Returns:	nothing
 **___________________________________________________			     */
-#define VerbosePrint1(A)	(void)fprintf(err_file,err_fmt1,"---",A)
+#define VerbosePrint1(A)	(void)fprintf(err_file,"--- BibTool: %s\n",A)
 
 /*-----------------------------------------------------------------------------
 ** Macro:	VerbosePrint2()
@@ -288,7 +298,7 @@
 **	B	Continuation of verbose message.
 ** Returns:	nothing
 **___________________________________________________			     */
-#define VerbosePrint2(A,B)	(void)fprintf(err_file,err_fmt2,"---",A,B)
+#define VerbosePrint2(A,B)	(void)fprintf(err_file,"--- BibTool: %s%s\n",A,B)
 
 /*-----------------------------------------------------------------------------
 ** Macro:	VerbosePrint3()
@@ -301,7 +311,7 @@
 **	C	Second continuation of verbose message.
 ** Returns:	nothing
 **___________________________________________________			     */
-#define VerbosePrint3(A,B,C)	(void)fprintf(err_file,err_fmt3,"---",A,B,C)
+#define VerbosePrint3(A,B,C)	(void)fprintf(err_file,"--- BibTool: %s%s%s\n",A,B,C)
 
 /*-----------------------------------------------------------------------------
 ** Macro:	VerbosePrint4()
@@ -315,7 +325,7 @@
 **	D	Third continuation of verbose message.
 ** Returns:	nothing
 **___________________________________________________			     */
-#define VerbosePrint4(A,B,C,D)	(void)fprintf(err_file,err_fmt4,"---",A,B,C,D)
+#define VerbosePrint4(A,B,C,D)	(void)fprintf(err_file,"--- BibTool: %s%s%s%s\n",A,B,C,D)
 
 #ifdef DEBUG
 
@@ -327,10 +337,10 @@
 **		simply ignores it. This is achieved by defining or
 **		undefining the macro |DEBUG| when compiling.
 ** Arguments:
-**	A	Debugging message.
+**	A	Debug message.
 ** Returns:	nothing
 **___________________________________________________			     */
-#define DebugPrint1(A)		(void)fprintf(err_file,err_fmt1,"+++",A)
+#define DebugPrint1(A)		(void)fprintf(err_file,"+++ BibTool: %s\n",A)
 
 /*-----------------------------------------------------------------------------
 ** Macro:	DebugPrint2()
@@ -340,11 +350,11 @@
 **		simply ignores them. This is achieved by defining or
 **		undefining the macro |DEBUG| when compiling.
 ** Arguments:
-**	A	Debugging message.
-**	B	Continuation of the debugging message.
+**	A	Debug message.
+**	B	Conitnuation of the debug message.
 ** Returns:	nothing
 **___________________________________________________			     */
-#define DebugPrint2(A,B)	(void)fprintf(err_file,err_fmt2,"+++",A,B)
+#define DebugPrint2(A,B)	(void)fprintf(err_file,"+++ BibTool: %s%s\n",A,B)
 
 /*-----------------------------------------------------------------------------
 ** Macro:	DebugPrint3()
@@ -355,12 +365,12 @@
 **		simply ignores them. This is achieved by defining or
 **		undefining the macro |DEBUG| when compiling.
 ** Arguments:Debug message.
-**	A	Debugging message.
-**	B	Continuation of the debugging message.
-**	C	Second continuation of the debugging message.
+**	A	Debug message.
+**	B	Conitnuation of the debug message.
+**	C	Second conitnuation of the debug message.
 ** Returns:	nothing
 **___________________________________________________			     */
-#define DebugPrint3(A,B,C)	(void)fprintf(err_file,err_fmt3,"+++",A,B,C)
+#define DebugPrint3(A,B,C)	(void)fprintf(err_file,"+++ BibTool: %s%s%s\n",A,B,C)
 #else
 #define DebugPrint1(A)	      
 #define DebugPrint2(A,B)      
@@ -368,10 +378,12 @@
 #endif
 
 
+
 #ifdef __STDC__
 #define _ARG(A) A
 #else
 #define _ARG(A) ()
 #endif
- void error _ARG((int type,Uchar *s1,Uchar *s2,Uchar *s3,Uchar *line,Uchar *err_pos,int line_no,char *fname));
- void init_error _ARG((void));
+ void error _ARG((int type,Uchar *s1,Uchar *s2,Uchar *s3,Uchar *line,Uchar *ep,int line_no,char *file_name));/* error.c*/
+ void init_error _ARG((FILE * file));
+
