@@ -1,15 +1,14 @@
 /******************************************************************************
-** $Id: resource.h,v 2.27 1999/12/18 22:04:46 gerd Exp $
+** $Id: resource.h,v 2.26 1997/10/30 22:07:22 gerd Exp $
 **=============================================================================
 ** 
 ** This file is part of BibTool.
 ** It is distributed under the GNU General Public License.
 ** See the file COPYING for details.
 ** 
-** (c) 1996-1999 Gerd Neugebauer
+** (c) 1996-2002 Gerd Neugebauer
 ** 
-** Net: gerd.neugebauer@sdm.de
-**      gerd.neugebauer@gmx.de
+** Net: gene@gerd-neugebauer.de
 ** 
 **-----------------------------------------------------------------------------
 ** Description:
@@ -130,10 +129,12 @@ RSC_NEXT('s')
   RscString(  "select.fields"	      , r_self,rsc_sel_fields     , "$key"  ) 
   RscByFct(   "select.non"	      , r_seln,add_extract(val,TRUE,TRUE)   )
   RscBoolean( "sort"		      , r_s   ,rsc_sort		  , FALSE   )
+  RscBoolean( "sort.cased"	      , r_sc  ,rsc_sort_cased     , FALSE   )
   RscBoolean( "sort.macros"	      , r_sm  ,rsc_srt_macs	  , TRUE    )
   RscBoolean( "sort.reverse"	      , r_sr  ,rsc_sort_reverse   , FALSE   )
   RscByFct(   "sort.order"	      , r_so  ,add_sort_order(val)	    )
   RscByFct(   "sort.format"	      , r_sf  ,add_sort_format(val)	    )
+  RscBoolean( "suppress.initial.newline", r_sin ,rsc_no_nl	  , FALSE   )
   RscByFct(   "symbol.type"	      , r_st  ,set_symbol_type(val)	    )
 RSC_NEXT('t')
   RscByFct(   "tex.define"	      , r_td  ,TeX_def(val)		    ) 
