@@ -1,15 +1,14 @@
 /******************************************************************************
-** $Id: init.c,v 1.3 1999/12/18 22:04:46 gerd Exp $
+** $Id: init.c,v 1.2 1997/12/06 22:56:00 gerd Exp gerd $
 **=============================================================================
 ** 
 ** This file is part of BibTool.
 ** It is distributed under the GNU General Public License.
 ** See the file COPYING for details.
 ** 
-** (c) 1996-1999 Gerd Neugebauer
+** (c) 1996-2002 Gerd Neugebauer
 ** 
-** Net: gerd.neugebauer@sdm.de
-**      gerd.neugebauer@gmx.de
+** Net: gene@gerd-neugebauer.de
 ** 
 **-----------------------------------------------------------------------------
 ** Description:
@@ -24,7 +23,6 @@
 #include <bibtool/rsc.h>
 #include <bibtool/key.h>
 #include <bibtool/entry.h>
-#include <bibtool/error.h>
 #include <bibtool/symbols.h>
 #include <bibtool/macros.h>
 #include <bibtool/parse.h>
@@ -84,7 +82,6 @@ void init_bibtool(progname)			   /*                        */
 #endif
 #endif
 						   /*			     */
-  init_error();					   /*			     */
   init_type();					   /*			     */
   init_symbols();				   /*			     */
   init_entries();				   /*			     */
