@@ -1,15 +1,14 @@
 /******************************************************************************
-** $Id: main.c,v 2.35 1999/12/18 22:04:46 gerd Exp $
+** $Id: main.c,v 2.34 1997/12/06 22:56:00 gerd Exp gerd $
 **=============================================================================
 ** 
 ** This file is part of BibTool.
 ** It is distributed under the GNU General Public License.
 ** See the file COPYING for details.
 ** 
-** (c) 1996-1999 Gerd Neugebauer
+** (c) 1996-2002 Gerd Neugebauer
 ** 
-** Net: gerd.neugebauer@sdm.de
-**      gerd.neugebauer@gmx.de
+** Net: gene@gerd-neugebauer.de
 ** 
 ** >>> See the file Doc/c_lib.tex for a printed documentation of the
 ** >>> main parts of the C source.
@@ -80,19 +79,19 @@
 #else
 #define _ARG(A) ()
 #endif
- int main _ARG((int argc,char *argv[]));
- static int dbl_check _ARG((DB db,Record rec));
- static int do_keys _ARG((DB db,Record rec));
- static int do_no_keys _ARG((DB db,Record rec));
- static int rec_gt _ARG((Record r1,Record r2));
- static int rec_lt _ARG((Record r1,Record r2));
- static int rec_read _ARG((DB db,Record rec));
- static int update_crossref _ARG((DB db,Record rec));
- static void usage _ARG((int fullp));
- void printchar _ARG((char c));
- void save_input_file _ARG((char *file));
- void save_macro_file _ARG((char *file));
- void save_output_file _ARG((char * file));
+ int main _ARG((int argc,char *argv[]));	   /* main.c                 */
+ static int dbl_check _ARG((DB db,Record rec));	   /* main.c                 */
+ static int do_keys _ARG((DB db,Record rec));	   /* main.c                 */
+ static int do_no_keys _ARG((DB db,Record rec));   /* main.c                 */
+ static int rec_gt _ARG((Record r1,Record r2));	   /* main.c                 */
+ static int rec_gt_cased _ARG((Record r1,Record r2));/* main.c               */
+ static int rec_lt _ARG((Record r1,Record r2));	   /* main.c                 */
+ static int rec_lt_cased _ARG((Record r1,Record r2));/* main.c               */
+ static int update_crossref _ARG((DB db,Record rec));/* main.c               */
+ static void usage _ARG((int fullp));		   /* main.c                 */
+ void save_input_file _ARG((char *file));	   /* main.c                 */
+ void save_macro_file _ARG((char *file));	   /* main.c                 */
+ void save_output_file _ARG((char * file));	   /* main.c                 */
 
 /*****************************************************************************/
 /* External Programs and Variables					     */
@@ -153,8 +152,8 @@ char * getenv(name)				   /*			     */
     "\t%c$\t\tSymbol table output (debugging only)\n",
 #endif
     0L,
-    "Copyright (C) Gerd Neugebauer $Date: 1999/12/18 22:04:46 $",
-    "gerd.neugebauer@sdm.de"
+    "Copyright (C) Gerd Neugebauer $Date: 1997/12/06 22:56:00 $",
+    "gerd@informatik.uni-koblenz.de"
   };
 
 /*-----------------------------------------------------------------------------
@@ -332,10 +331,6 @@ void save_macro_file(file)			   /*			     */
 
 #define Toggle(X) X = !(X)
 
- static int stat_len;				   /*                        */
- static int *stat_count;			   /*                        */
-
-
 /*-----------------------------------------------------------------------------
 ** Function:	main()
 ** Purpose:	This is the main function which is automatically
@@ -365,6 +360,10 @@ int main(argc,argv)				   /*			     */
   FILE	*file;				   	   /*                        */
   int	need_rsc = TRUE;		   	   /*			     */
   int	(*fct)();			   	   /* Function pointer	     */
+  int	c_len;					   /*                        */
+  int   *c;					   /*                        */
+ 						   /*                        */
+  init_error(stderr);				   /*                        */
   init_bibtool(argv[0]);			   /*                        */
 						   /*			     */
   for ( i=1; i<argc; i++ )			   /*			     */
@@ -397,7 +396,7 @@ int main(argc,argv)				   /*			     */
 	  else					   /*                        */
 	  {  NoRscError(argv[i]); }		   /*                        */
 	  break;				   /*			     */
-	case 'R': need_rsc = search_rsc();  break; /* default resource file  */
+	case 'R': need_rsc |= !search_rsc();break; /* default resource file  */
 	case 's': Toggle(rsc_sort);	    break; /* sort		     */
 	case 'S':				   /*			     */
 	  Toggle(rsc_sort);			   /*			     */
@@ -409,7 +408,7 @@ int main(argc,argv)				   /*			     */
 	  rsc_all_macs = FALSE;			   /*                        */
 	  if ( ++i < argc )			   /*			     */
 	  { if ( read_aux(argv[i],save_input_file,*++ap=='v') )/*            */
-	    { ERROR3("aux File ",argv[i]," not found.");/*                   */
+	    { ERROR3("aux file ",argv[i]," not found.");/*                   */
 	    }					   /*                        */
 	  }					   /*                        */
 	  else		    { NoSFileWarning; }	   /*			     */
@@ -445,35 +444,28 @@ int main(argc,argv)				   /*			     */
   init_read();					   /* Just in case the path  */
  						   /*  has been modified.    */
   the_db = new_db();				   /*                        */
-  						   /*                        */
-  (void) db_count(the_db,&stat_len);	   	   /* Determine the numer of */
- 						   /* registered record types*/
-  if ( (stat_count=(int*)malloc(stat_len*sizeof(int))) == NULL )/*           */
-  { OUT_OF_MEMORY("count"); }			   /*                        */
-  else					   	   /*                        */
-  { for (i=0;i<stat_len;i++)			   /*                        */
-    { stat_count[i] = 0; }			   /*                        */
-  }						   /*                        */
 						   /*			     */
   for ( i=0; i<input_file_ptr; i++ )		   /* For all input files    */
   {						   /*			     */
     if ( read_db(the_db,			   /*                        */
 		 input_files[i],		   /*                        */
-		 rec_read,			   /*                        */
+		 is_selected,			   /*                        */
 		 rsc_verbose) )	   		   /*                        */
     { NoFileError(input_files[i]); }		   /*			     */
   }						   /*			     */
  						   /*                        */
+  apply_aux(the_db);				   /*                        */
+ 						   /*                        */
   if ( rsc_cnt_all || rsc_cnt_used )		   /*			     */
   { int i;					   /*                        */
-    int *count = db_count_special(the_db,(int*)NULL);/*                      */
-						   /*                        */
-    for (i=0; i<stat_len && IsSpecialRecord(i); ++i)/*			     */
-    { stat_count[i] = count[i];			   /*			     */
-    }						   /*			     */
-  }						   /*                        */
+    int * cnt = db_count(the_db,&c_len);	   /*                        */
  						   /*                        */
-  apply_aux(the_db);				   /*                        */
+    if ( (c=(int*)malloc(c_len*sizeof(int))) == NULL )/*                     */
+    { rsc_cnt_all = rsc_cnt_used = 0; }		   /*                        */
+    else					   /*                        */
+    { for (i=0;i<c_len;i++) c[i] = cnt[i];	   /*                        */
+    }						   /*                        */
+  }						   /*                        */
 						   /*			     */
   if ( rsc_make_key )				   /*                        */
   {						   /*                        */
@@ -490,9 +482,16 @@ int main(argc,argv)				   /*			     */
     db_forall(the_db,do_no_keys);		   /*                        */
   }						   /*                        */
  						   /*                        */
-  if ( rsc_sort ) {				   /*                        */
-    if ( rsc_sort_reverse ) fct = rec_lt;	   /*                        */
-    else		    fct = rec_gt;	   /*                        */
+  if ( rsc_sort )				   /*                        */
+  {				   		   /*                        */
+    if ( rsc_sort_cased )			   /*                        */
+    { if ( rsc_sort_reverse ) fct = rec_lt_cased;  /*                        */
+      else		      fct = rec_gt_cased;  /*                        */
+    }						   /*                        */
+    else					   /*                        */
+    { if ( rsc_sort_reverse ) fct = rec_lt;	   /*                        */
+      else		      fct = rec_gt;	   /*                        */
+    }						   /*                        */
     db_sort(the_db,fct);			   /*                        */
   }						   /*                        */
  						   /*                        */
@@ -521,16 +520,15 @@ int main(argc,argv)				   /*			     */
 						   /*			     */
   if ( rsc_cnt_all || rsc_cnt_used )		   /*			     */
   { int i;					   /*                        */
-    int *count = db_count(the_db,(int*)NULL);	   /*                        */
+    int *cnt = db_count(the_db,(int*)NULL);	   /*                        */
 						   /*                        */
-    (void)fputc('\n',err_file);		   	   /*			     */
-    for (i=0; i<stat_len; ++i)			   /*			     */
-    { if ( rsc_cnt_all || stat_count[i] > 0 )	   /*			     */
-      { (void)fprintf(err_file,			   /*			     */
-		      "---  %-15s %5d read  %5d written\n",/*		     */
-		      get_entry_type(i),	   /*			     */
-		      stat_count[i],		   /*			     */
-		      count[i]);		   /*			     */
+    ErrC('\n');		   	   	   	   /*			     */
+    for (i=0; i<c_len; ++i)			   /*			     */
+    { if ( rsc_cnt_all || c[i] > 0 )	   	   /*			     */
+      { ErrPrintF3("---  %-15s %5d read  %5d written\n",/*		     */
+		   get_entry_type(i),	   	   /*			     */
+		   c[i],		   	   /*			     */
+		   cnt[i]);		   	   /*			     */
       }						   /*			     */
     }						   /*			     */
   }						   /*                        */
@@ -550,23 +548,6 @@ int main(argc,argv)				   /*			     */
   return 0;					   /*			     */
 }						   /*------------------------*/
 
-/*-----------------------------------------------------------------------------
-** Function:	rec_read()
-** Type:	static int
-** Purpose:	This is a boolean callback function used whenever a
-**		record is read. 
-** Arguments:
-**	db	The current database
-**	rec	The current record
-** Returns:	|TRUE| iff the record should be inserted into the database.
-**___________________________________________________			     */
-static int rec_read(db,rec)			   /*                        */
-  DB db;					   /*                        */
-  Record rec;					   /*                        */
-{ stat_count[RecordType(rec)]++;		   /*                        */
-  return is_selected(db,rec);			   /*                        */
-}						   /*------------------------*/
-
 /*-----------------------------------------------------------------------------
 ** Function:	rec_gt()
 ** Purpose:	
@@ -601,6 +582,40 @@ static int rec_lt(r1,r2)			   /*                        */
 		 (char*)RecordSortkey(r2)) > 0);   /*                        */
 }						   /*------------------------*/
 
+/*-----------------------------------------------------------------------------
+** Function:	rec_gt_cased()
+** Type:	static int
+** Purpose:	
+**		
+** Arguments:
+**	r1	
+**	r2	
+** Returns:	
+**___________________________________________________			     */
+static int rec_gt_cased(r1,r2)			   /*                        */
+  Record r1;					   /*                        */
+  Record r2;					   /*                        */
+{ return (strcmp((char*)get_key_name(RecordSortkey(r1)),/*                   */
+		 (char*)get_key_name(RecordSortkey(r2))) < 0);/*             */
+}						   /*------------------------*/
+
+/*-----------------------------------------------------------------------------
+** Function:	rec_lt_cased()
+** Type:	static int
+** Purpose:	
+**		
+** Arguments:
+**	r1	
+**	r2	
+** Returns:	
+**___________________________________________________			     */
+static int rec_lt_cased(r1,r2)			   /*                        */
+  Record r1;					   /*                        */
+  Record r2;					   /*                        */
+{ return (strcmp((char*)get_key_name(RecordSortkey(r1)),/*                   */
+		 (char*)get_key_name(RecordSortkey(r2))) > 0);/*             */
+}						   /*------------------------*/
+
 /*-----------------------------------------------------------------------------
 ** Function:	do_keys()
 ** Purpose:	
@@ -707,21 +722,21 @@ static int dbl_check(db,rec)			   /*                        */
 {						   /*                        */
   if ( PrevRecord(rec) != RecordNULL		   /*                        */
        && equal_records(PrevRecord(rec),rec) )	   /*			     */
-  {						   /*                        */
-    if ( !rsc_quiet )				   /*                        */
-    { Uchar *k1 = *RecordHeap(rec);		   /*                        */
-      Uchar *k2 = *RecordHeap(PrevRecord(rec));	   /*                        */
+  {
+    if ( !rsc_quiet )
+    { Uchar *k1 = *RecordHeap(rec);
+      Uchar *k2 = *RecordHeap(PrevRecord(rec));
       ErrPrint("*** BibTool WARNING: Possible double entries discovered: \n***\t");
-      if ( k1 == (Uchar*)NULL ) k1 = (Uchar*)"";   /*                        */
-      if ( k2 == (Uchar*)NULL ) k2 = (Uchar*)"";   /*                        */
-      ErrPrint(k2);				   /*                        */
-      ErrPrint(" =?= ");			   /*                        */
-      ErrPrint(k1);				   /*                        */
-      ErrPrint("\n***\t");			   /*                        */
+      if ( k1 == NULL ) k1 = "";
+      if ( k2 == NULL ) k2 = "";
+      ErrPrint(k2);
+      ErrPrint(" =?= ");
+      ErrPrint(k1);
+      ErrPrint("\n***\t");
       ErrPrint(RecordSortkey(rec));		   /*			     */
       ErrPrint("\n");				   /*                        */
     }						   /*                        */
-    if ( rsc_del_dbl )				   /*                        */
+    if (rsc_del_dbl)				   /*                        */
     { delete_record(db,rec); }		   	   /*                        */
     else 					   /*                        */
     { SetRecordDELETED(rec); }			   /*                        */
@@ -730,6 +745,7 @@ static int dbl_check(db,rec)			   /*                        */
   return 0;					   /*                        */
 }						   /*------------------------*/
 
+
 #ifdef DEBUG
 /*-----------------------------------------------------------------------------
 ** Function*:	printchar()
