@@ -1,15 +1,14 @@
 /******************************************************************************
-** $Id: names.c,v 1.7 1999/12/18 22:04:46 gerd Exp $
+** $Id: names.c,v 1.6 1997/12/03 11:50:30 gerd Exp $
 *******************************************************************************
 ** 
 ** This file is part of BibTool.
 ** It is distributed under the GNU General Public License.
 ** See the file COPYING for details.
 ** 
-** (c) 1996-1999 Gerd Neugebauer
+** (c) 1996-2002 Gerd Neugebauer
 ** 
-** Net: gerd.neugebauer@sdm.de
-**      gerd.neugebauer@gmx.de
+** Net: gene@gerd-neugebauer.de
 ** 
 ******************************************************************************/
 
@@ -138,9 +137,9 @@ static void dump_name_node(n)			   /*                        */
   }						   /*                        */
   fprintf(err_file,				   /*                        */
 	  "[%s][%s][%s]\n",			   /*                        */
-	  (NamePre(n)?NamePre(n):""),		   /*                        */
-	  (NameMid(n)?NameMid(n):""),		   /*                        */
-	  (NamePost(n)?NamePost(n):""));	   /*                        */
+	  (NamePre(n)?(char*)NamePre(n):""),	   /*                        */
+	  (NameMid(n)?(char*)NameMid(n):""),	   /*                        */
+	  (NamePost(n)?(char*)NamePost(n):""));	   /*                        */
 }						   /*------------------------*/
 #endif
 
@@ -570,7 +569,7 @@ static void initial(s,trans,len,sb)		   /*                        */
   while ( len > 0 )				   /*                        */
   { if (*s=='\0') { return; }			   /*                        */
     if ( is_alpha(*s) )				   /*                        */
-    { sbputc(trans[*s],sb);			   /*                        */
+    { sbputc(trans[*((unsigned char *)s)],sb);	   /*                        */
       len--;					   /*                        */
     }						   /*                        */
     s++;					   /*                        */
