@@ -1,15 +1,14 @@
 /******************************************************************************
-** $Id: print.c,v 2.31 1999/12/18 22:04:46 gerd Exp $
+** $Id: print.c,v 2.30 1997/12/06 18:57:08 gerd Exp $
 **=============================================================================
 ** 
 ** This file is part of BibTool.
 ** It is distributed under the GNU General Public License.
 ** See the file COPYING for details.
 ** 
-** (c) 1996-1999 Gerd Neugebauer
+** (c) 1996-2002 Gerd Neugebauer
 ** 
-** Net: gerd.neugebauer@sdm.de
-**      gerd.neugebauer@gmx.de
+** Net: gene@gerd-neugebauer.de
 ** 
 **-----------------------------------------------------------------------------
 ** Description:
@@ -360,7 +359,7 @@ static void print_equation(pre,s,t,align,fct)	   /*			     */
   }						   /*			     */
 }						   /*------------------------*/
 
- static FILE * ofile = NULL;
+ static FILE * ofile=NULL;
 
 /*-----------------------------------------------------------------------------
 ** Function:	fput_char()
@@ -494,11 +493,13 @@ void put_record(fct,rec,db,start)		   /*                        */
 { Uchar	       **hp;			   	   /* heap pointer	     */
   unsigned int i;			   	   /*			     */
   char	       open_brace, close_brace;		   /*			     */
+  static int   first = 1;
   						   /*                        */
   sort_record(rec);				   /*                        */
  						   /*                        */
   hp = RecordHeap(rec);				   /*			     */
-  if ( IsNormalRecord(RecordType(rec)) ) { NL; }   /*			     */
+  if ( rsc_no_nl && first ) { first = 0; }
+  else if ( IsNormalRecord(RecordType(rec)) ) { NL; }/*			     */
  						   /*                        */
   if ( *RecordComment(rec) )		   	   /*                        */
   { PUTS(RecordComment(rec));			   /*                        */
