@@ -1,15 +1,14 @@
 /******************************************************************************
-** $Id: rewrite.c,v 2.27 1999/12/18 22:04:46 gerd Exp $
+** $Id: rewrite.c,v 2.26 1997/12/03 11:50:30 gerd Exp $
 **=============================================================================
 ** 
 ** This file is part of BibTool.
 ** It is distributed under the GNU General Public License.
 ** See the file COPYING for details.
 ** 
-** (c) 1996-1999 Gerd Neugebauer
+** (c) 1996-2002 Gerd Neugebauer
 ** 
-** Net: gerd.neugebauer@sdm.de
-**      gerd.neugebauer@gmx.de
+** Net: gene@gerd-neugebauer.de
 ** 
 ******************************************************************************/
 
@@ -69,7 +68,6 @@
  static int s_match _ARG((Uchar * p,Uchar * s));
  static int s_search _ARG((Uchar * pattern,Uchar * s));
  static void add_rule _ARG((Uchar *s,Rule *rp,Rule *rp_end,int flags,int casep));
- static void free_rule _ARG((Rule rule));
  static void init_s_search _ARG((char * ignored));
  static void rewrite_1 _ARG((Uchar *frame,StringBuffer *sb,Uchar *match,DB db,Record rec));
  void add_check_rule _ARG((Uchar *s));
@@ -792,15 +790,15 @@ static int s_match(p,s)				   /*                        */
 {						   /*                        */
   while ( *p && s_class[(unsigned int)*p] == '\0' ) p++;/*                   */
  						   /*                        */
-  while ( *p )
-  {
+  while ( *p )					   /*                        */
+  {						   /*                        */
     while ( *s && s_class[(unsigned int)*s] == '\0' ) s++;
     /*printf(" '%c' [%c] =?= '%c' [%c]\n",*s,s_class[*s],*p,s_class[*p] );*/
     if ( s_class[(unsigned int)*s] != s_class[(unsigned int)*p] ) return FALSE;
-    while ( *p && s_class[(unsigned int)*p] == '\0' ) p++;
-    if (*s) s++;
-    if (*p) p++;
-  }
+    while ( *p && s_class[(unsigned int)*p] == '\0' ) p++;/*                 */
+    if (*s) s++;				   /*                        */
+    if (*p) p++;				   /*                        */
+  }						   /*                        */
   return TRUE;					   /*                        */
 }						   /*------------------------*/
 
@@ -869,6 +867,15 @@ int is_selected(db,rec)	   		   	   /*			     */
       if ( RuleFlag(rule) & RULE_REGEXP )	   /*                        */
       {						   /*                        */
 #ifdef REGEX
+	if ( RecordHeap(rec)[0] )		   /*                        */
+	{ len = strlen((char*)(RecordHeap(rec)[0]));/*                       */
+	  ReturnIf(re_search(&RulePattern(rule),   /*			     */
+			     RecordHeap(rec)[0],   /*                        */
+			     len,		   /*                        */
+			     0,		   	   /*                        */
+			     len-1,		   /*                        */
+			     &reg) >=0 );	   /*		             */
+	}					   /*                        */
 	for ( i=2; i < RecordFree(rec); i+=2 )	   /*                        */
 	{ if ( RecordHeap(rec)[i] )		   /*                        */
 	  { len = strlen((char*)(RecordHeap(rec)[i+1]));/*                   */
@@ -884,11 +891,15 @@ int is_selected(db,rec)	   		   	   /*			     */
       }						   /*                        */
       else					   /*                        */
       {						   /*                        */
+	if ( RecordHeap(rec)[0] )		   /*                        */
+	{ ReturnIf(s_search(RuleGoal(rule),	   /*			     */
+			    RecordHeap(rec)[0]) ); /*		             */
+	}					   /*                        */
 	for ( i=2; i < RecordFree(rec); i+=2 )	   /*                        */
-	{ if ( RecordHeap(rec)[i] )
+	{ if ( RecordHeap(rec)[i] )		   /*                        */
 	  { ReturnIf(s_search(RuleGoal(rule),	   /*			     */
 			      RecordHeap(rec)[i+1]) );/*		     */
-	  }
+	  }					   /*                        */
 	}					   /*                        */
       }						   /*                        */
     }						   /*                        */
