@@ -1,15 +1,14 @@
 /******************************************************************************
-** $Id: symbols.c,v 2.21 1999/12/18 22:04:46 gerd Exp $
+** $Id: symbols.c,v 2.20 1997/12/06 22:56:00 gerd Exp gerd $
 **=============================================================================
 ** 
 ** This file is part of BibTool.
 ** It is distributed under the GNU General Public License.
 ** See the file COPYING for details.
 ** 
-** (c) 1996-1999 Gerd Neugebauer
+** (c) 1996-2002 Gerd Neugebauer
 ** 
-** Net: gerd.neugebauer@sdm.de
-**      gerd.neugebauer@gmx.de
+** Net: gene@gerd-neugebauer.de
 ** 
 **-----------------------------------------------------------------------------
 ** Description:
@@ -387,7 +386,7 @@ void sym_gc()					   /*                        */
     while (sym_tab[i] && SymbolUsed(sym_tab[i])<=0)
     { st = sym_tab[i];
       sym_tab[i] = NextSymbol(st);
-      if ( SymbolFlags(st) & SYMBOL_STATIC == 0 )
+      if ( (SymbolFlags(st) & SYMBOL_STATIC) == 0 )
       { free(SymbolName(st)); }
       free(st);
     }
@@ -397,7 +396,7 @@ void sym_gc()					   /*                        */
       while ( (st2=NextSymbol(st)) != NULL &&
 	      SymbolUsed(st) <= 0 )
       { NextSymbol(st) = NextSymbol(st2);
-        if ( SymbolFlags(st2) & SYMBOL_STATIC == 0 )
+        if ( (SymbolFlags(st2) & SYMBOL_STATIC) == 0 )
 	{ free(SymbolName(st2)); }
 	free(st2);
       }						   /*                        */
