@@ -1,16 +1,16 @@
 /******************************************************************************
-** $Id: tex_read.c,v 2.21 1999/12/18 22:04:46 gerd Exp $
+** $Id: tex_read.c,v 2.20 1997/12/03 11:50:30 gerd Exp $
 **=============================================================================
 ** 
 ** This file is part of BibTool.
 ** It is distributed under the GNU General Public License.
 ** See the file COPYING for details.
 ** 
-** (c) 1996-1999 Gerd Neugebauer
+** (c) 1996-2002 Gerd Neugebauer
 ** 
-** Net: gerd.neugebauer@sdm.de
-**      gerd.neugebauer@gmx.de
+** Net: gene@gerd-neugebauer.de
 **	    
+** 
 ** Purpose: Simulate the TeX reading mechanism.
 **
 ** Compilation: cc tex_read.c -o tex_read -DSTANDALONE
@@ -41,7 +41,6 @@
 
 #define CARET_CARET	    /* enable ^^A type specification of unprintables */
 #undef	TRANSLATE_NEWLINE   /* Translate nl to space or \par */
-#undef  USE_EXTENDED_AS_LETTERS /* Set the catcode of characters >=160 */
 
  typedef struct tOKEN				   /*			     */
  { short int	 to_char;			   /*			     */
@@ -178,9 +177,6 @@ static void init_TeX()				   /*			     */
   for ( i=0; i<256; ++i )			   /*			     */
   { active[i]  = MacDefNULL;			   /*			     */
     catcode[i] = (  isalpha(i)			   /*			     */
-#ifdef USE_EXTENDED_AS_LETTERS
-		    || i >= 160			   /*                        */
-#endif
 		  ? CATCODE_LETTER		   /*			     */
 		  : CATCODE_OTHER  );		   /*			     */
   }						   /*			     */
